pub trait FutureSpawner {
    // Required method
    fn spawn_boxed_future(&self, future: BoxFuture<'static, ()>);
}
Future executor must implement this trait to support register to hala register system.

Required Methods

source

fn spawn_boxed_future(&self, future: BoxFuture<'static, ()>)

The implementation must panic if this function spawn future failed.

Implementations on Foreign Types

source

impl FutureSpawner for ThreadPool

source

fn spawn_boxed_future(&self, future: BoxFuture<'static, ()>)

Implementors